@@ -3,33 +3,7 @@
 # Projekt von https://github.com/rix1337
 # Dieses Modul initialisiert die globalen Parameter und starte alle parallel laufenden Threads des FeedCrawlers.
 
-"""
-FeedCrawler.
-Usage:
-  main.py [--config="<CFGPFAD>"]
-                [--test_run]
-                [--docker]
-                [--port=<PORT>]
-                [--jd-user=<NUTZERNAME>]
-                [--jd-pass=<PASSWORT>]
-                [--jd-device=<GERÄTENAME>]
-                [--keep-cdc]
-                [--remove-f_time]
-                [--log-level=<LOGLEVEL>]
-
-Options:
-  --log-level=<LOGLEVEL>    Legt fest, wie genau geloggt wird (CRITICAL, ERROR, WARNING, INFO, DEBUG, NOTSET )
-  --config="<CFGPFAD>"      Legt den Ablageort für Einstellungen und Logs fest
-  --port=<PORT>             Legt den Port des Webservers fest
-  --jd-user=NUTZERNAME      Legt den Nutzernamen für My JDownloader fest
-  --jd-pass=PASSWORT        Legt das Passwort für My JDownloader fest
-  --jd-device=GERÄTENAME    Legt den Gerätenamen für My JDownloader fest
-  --keep-cdc                Leere die CDC-Tabelle (Feed ab hier bereits gecrawlt) nicht vor dem ersten Suchlauf
-  --remove-f_time           Leere die Zeit des letzten SF/FF-Laufes vor dem ersten Suchlauf
-  --test_run                Intern: Führt einen Testlauf durch
-  --docker                  Intern: Sperre Pfad und Port auf Docker-Standardwerte (um falsche Einstellungen zu vermeiden)
-"""
-
+import argparse
 import logging
 import multiprocessing
 import os
@@ -38,10 +12,6 @@ import signal
 import sys
 import time
 
-from docopt import docopt
-from requests.packages.urllib3 import disable_warnings as disable_request_warnings
-from requests.packages.urllib3.exceptions import InsecureRequestWarning
-
 from feedcrawler import common
 from feedcrawler import internal
 from feedcrawler import myjd
@@ -58,17 +28,30 @@ version = "v." + version.get_version()
 
 
 def main():
-    arguments = docopt(__doc__, version='FeedCrawler')
+    parser = argparse.ArgumentParser()
+    parser.add_argument("--log-level", help="Legt fest, wie genau geloggt wird (INFO, DEBUG)")
+    parser.add_argument("--config", help="Legt den Ablageort für Einstellungen und Logs fest")
+    parser.add_argument("--port", help="Legt den Port des Webservers fest")
+    parser.add_argument("--jd-user", help="Legt den Nutzernamen für My JDownloader fest")
+    parser.add_argument("--jd-pass", help="Legt das Passwort für My JDownloader fest")
+    parser.add_argument("--jd-device", help="Legt den Gerätenamen für My JDownloader fest")
+    parser.add_argument("--keep-cdc", action='store_true',
+                        help="Vergisst 'Feed ab hier bereits gecrawlt' nicht vor dem ersten Suchlauf")
+    parser.add_argument("--remove-f_time", action='store_true',
+                        help="Leere die Zeit des letzten SF/FF-Laufes vor dem ersten Suchlauf")
+    parser.add_argument("--test_run", action='store_true', help="Intern: Führt einen Testlauf durch")
+    parser.add_argument("--docker", action='store_true', help="Intern: Sperre Pfad und Port auf Docker-Standardwerte")
+    arguments = parser.parse_args()
 
     print(u"┌──────────────────────────────────────────────┐")
     print(u"  FeedCrawler " + version + " von RiX")
     print(u"  https://github.com/rix1337/FeedCrawler")
     print(u"└──────────────────────────────────────────────┘")
 
-    if arguments['--docker']:
+    if arguments.docker:
         configpath = "/config"
     else:
-        configpath = common.configpath(arguments['--config'])
+        configpath = common.configpath(arguments.config)
 
     internal.set_files(configpath)
 
@@ -78,7 +61,7 @@ def main():
     print(u"Nutze das Verzeichnis " + configpath + u" für Einstellungen/Logs")
 
     log_level = logging.__dict__[
-        arguments['--log-level']] if arguments['--log-level'] in logging.__dict__ else logging.INFO
+        arguments.log_level] if arguments.log_level in logging.__dict__ else logging.INFO
 
     internal.set_logger(log_level)
 
@@ -105,22 +88,20 @@ def main():
         if hostname:
             set_hostnames[name] = hostname
 
-    if not arguments['--test_run'] and not set_hostnames:
+    if not arguments.test_run and not set_hostnames:
         print(u'Keine Hostnamen in der FeedCrawler.ini gefunden! Beende FeedCrawler!')
         time.sleep(10)
         sys.exit(1)
 
-    disable_request_warnings(InsecureRequestWarning)
-
-    if not arguments['--test_run']:
+    if not arguments.test_run:
         if not os.path.exists(internal.configfile):
-            if arguments['--docker']:
-                if arguments['--jd-user'] and arguments['--jd-pass']:
-                    myjd.myjd_input(arguments['--port'], arguments['--jd-user'], arguments['--jd-pass'],
-                                    arguments['--jd-device'])
+            if arguments.docker:
+                if arguments.jd_user and arguments.jd_pass:
+                    myjd.myjd_input(arguments.port, arguments.jd_user, arguments.jd_pass,
+                                    arguments.jd_device)
             else:
-                myjd.myjd_input(arguments['--port'], arguments['--jd-user'], arguments['--jd-pass'],
-                                arguments['--jd-device'])
+                myjd.myjd_input(arguments.port, arguments.jd_user, arguments.jd_pass,
+                                arguments.jd_device)
         else:
             feedcrawler = CrawlerConfig('FeedCrawler')
             user = feedcrawler.get('myjd_user')
@@ -133,10 +114,10 @@ def main():
                         feedcrawler.save('myjd_device', one_device)
                         get_device()
             else:
-                myjd.myjd_input(arguments['--port'], arguments['--jd-user'], arguments['--jd-pass'],
-                                arguments['--jd-device'])
+                myjd.myjd_input(arguments.port, arguments.jd_user, arguments.jd_pass,
+                                arguments.jd_device)
 
-    if not arguments['--test_run']:
+    if not arguments.test_run:
         if not internal.device:
             print(u'My JDownloader Zugangsdaten fehlerhaft! Beende FeedCrawler!')
             time.sleep(10)
@@ -147,23 +128,23 @@ def main():
     feedcrawler = CrawlerConfig('FeedCrawler')
     port = int(feedcrawler.get("port"))
     docker = False
-    if arguments['--docker']:
+    if arguments.docker:
         port = int('9090')
         docker = True
-    elif arguments['--port']:
-        port = int(arguments['--port'])
+    elif arguments.port:
+        port = int(arguments.port)
 
     if feedcrawler.get("prefix"):
         prefix = '/' + feedcrawler.get("prefix")
     else:
         prefix = ''
     local_address = 'http://' + common.check_ip() + ':' + str(port) + prefix
-    if not arguments['--docker']:
+    if not arguments.docker:
         print(u'Der Webserver ist erreichbar unter ' + local_address)
 
     internal.set_connection_info(local_address, port, prefix, docker)
 
-    if arguments['--keep-cdc']:
+    if arguments.keep_cdc:
         print(u"CDC-Tabelle nicht geleert!")
     else:
         FeedDb('cdc').reset()
@@ -173,9 +154,9 @@ def main():
     p = multiprocessing.Process(target=web_server, args=(global_variables,))
     p.start()
 
-    if not arguments['--test_run']:
+    if not arguments.test_run:
         c = multiprocessing.Process(target=crawler,
-                                    args=(global_variables, arguments['--remove-f_time'], False,))
+                                    args=(global_variables, arguments.remove_f_time, False,))
         c.start()
 
         w = multiprocessing.Process(target=crawldog, args=(global_variables,))
@@ -197,7 +178,7 @@ def main():
             while True:
                 time.sleep(1)
     else:
-        crawler(global_variables, arguments['--remove-f_time'], True)
+        crawler(global_variables, arguments.remove_f_time, True)
         p.terminate()
         sys.exit(0)
 
